@@ -294,14 +294,20 @@
         <translation>Orixe e destino no mesmo dispositivo; seleccionar de novo.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="152"/>
         <source>Writing %1 using &apos;dd&apos; command to /dev/%2,
 
 Please wait until the the process is completed</source>
-        <translation>Gravando %1 en  /dev/%2, usando o comando &apos;dd&apos;.
+        <translation type="vanished">Gravando %1 en  /dev/%2, usando o comando &apos;dd&apos;.
 
 Agardar ata que o proceso rematar.</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="152"/>
+        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,
+
+Please wait until the process is completed</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="312"/>
         <source>Success</source>
