@@ -294,14 +294,20 @@
         <translation>Źródło i miejsce docelowe znajdują się na tym samym urządzeniu, proszę wybierz ponownie.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="152"/>
         <source>Writing %1 using &apos;dd&apos; command to /dev/%2,
 
 Please wait until the the process is completed</source>
-        <translation>Zapisywanie %1 przy użyciu polecenia &quot;dd&quot; do /dev/%2,
+        <translation type="vanished">Zapisywanie %1 przy użyciu polecenia &quot;dd&quot; do /dev/%2,
 
 Poczekaj, aż proces się zakończy.</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="152"/>
+        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,
+
+Please wait until the process is completed</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="312"/>
         <source>Success</source>
